@@ -38,25 +38,23 @@
 
 #include "keyrequester.h"
 
-#include <QPushButton>
 #include <KLocalizedString>
-#include <kseparator.h>
+#include <KSeparator>
 
-#include <QStringList>
-#include <QLabel>
+#include <QApplication>
 #include <QComboBox>
-#include <QScrollArea>
-#include <QPushButton>
-#include <QVBoxLayout>
+#include <QDesktopWidget>
+#include <QDialogButtonBox>
 #include <QGridLayout>
+#include <QLabel>
+#include <QPushButton>
+#include <QScrollArea>
+#include <QStringList>
+#include <QVBoxLayout>
 
 #include <gpgme++/key.h>
 #include <qgpgme/protocol.h>
 
-#include <QApplication>
-#include <QDesktopWidget>
-#include <QDialogButtonBox>
-
 static Kleo::EncryptionPreference cb2pref(int i)
 {
     switch (i) {
@@ -110,7 +108,7 @@ Kleo::KeyApprovalDialog::KeyApprovalDialog(const std::vector<Item> &recipients,
     : QDialog(parent),
       d(new Private())
 {
-    setWindowTitle(i18n("Encryption Key Approval"));
+    setWindowTitle(i18nc("@title:window", "Encryption Key Approval"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
